@@ -35,8 +35,12 @@
 #define	ENV_PATH	"PATH=/bin:/sbin:/usr/bin:/usr/sbin:"
 
 /* VPS states */
-#define STATE_STARTING  0
-#define STATE_RUNNING   1
+enum {
+	STATE_STARTING = 1,
+	STATE_RUNNING = 2,
+	STATE_STOPPED = 3,
+	STATE_STOPPING = 4,
+};
 
 /* Parse errro codes */
 #define ERR_DUP		-1
