@@ -50,8 +50,8 @@ int calculate(int numerator, int verbose)
 	struct CRusage ru_comm, ru_utl;
 	char str[STR_SIZE];
 	char name[STR_SIZE];
-	const char *fmt;
-	int veid, res, id, ret = 0, found = 0, new_veid = 0;
+	const char *fmt = NULL;
+	int veid = 0, res, id, ret = 0, found = 0, new_veid = 0;
 	int exited = 0;
 	double r, rs, lm, k;
 	struct mem_struct mem;
@@ -60,7 +60,7 @@ int calculate(int numerator, int verbose)
 	struct ub_struct ub_s;
 
 	if ((fd = fopen(PROCUBC, "r")) == NULL) {
-		fprintf(stderr, "Unable to open file " PROCUBC ": %s",
+		fprintf(stderr, "Unable to open file " PROCUBC ": %s\n",
 			strerror(errno));
 		return 1;
 	}
